@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2001, 2007 - 2010, 2016, 2018  Peter Pentchev
+ * Copyright (c) 2001, 2007 - 2010, 2016, 2018, 2021  Peter Pentchev
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -292,7 +292,7 @@ init(const int argc, char * const argv[]) {
 	}
 
 	if (listfeatures) {
-		puts("Features: timelimit=1.9.0"
+		puts("Features: timelimit=1.9.2"
 #ifdef HAVE_SETITIMER
 		    " subsecond=1.0"
 #endif
@@ -357,11 +357,13 @@ setsig_fatal_gen(const int sig, void (* const handler)(int), const bool nocld,
 	if (nocld)
 		act.sa_flags |= SA_NOCLDSTOP;
 #endif /* SA_NOCLDSTOP */
-	if (sigaction(sig, &act, NULL) < 0)
+	if (sigaction(sig, &act, NULL) < 0 &&
+	    !(errno == EINVAL && (sig == SIGKILL || sig == SIGSTOP)))
 		err(EX_OSERR, "%s signal handler for %d", what, sig);
 #else  /* HAVE_SIGACTION */
 	(void)nocld;
-	if (signal(sig, handler) == SIG_ERR)
+	if (signal(sig, handler) == SIG_ERR &&
+	    !(errno == EINVAL && (sig == SIGKILL || sig == SIGSTOP)))
 		err(EX_OSERR, "%s signal handler for %d", what, sig);
 #endif /* HAVE_SIGACTION */
 }
